#!/bin/sh
BUILD_INTERP=hpux10


 # Remove the file that start up errors are written to if it
 # exists before startup so we don't keep appending to it.
rm -f /tmp/hpov_start.err > /dev/null 2>&1

exec > /tmp/hpov_start.err 2>&1
set -x

 # This is a simple wrapper script that will source in the Tivoli
 #  environment and execute the real adapter with all of the flags
 #  provided.  The sed removes the '.sh' from $0.

 # Source the OV environment in case it is not set already so
 # that setting the SHLIB_PATH and LD_LIBRARY_PATH works
 # Exit if not the standard path and have the customer source the
 # environment
if [ -f /opt/OV/bin/ov.envvars.sh ]; then
  . /opt/OV/bin/ov.envvars.sh > /dev/null 2>& 1
else
  echo "Couldn't source the Openview environment." >> /tmp/hpov_start.err
  echo "Source and export the Openview environment and start the adapter again." >> /tmp/hpov_start.err
  exit 1
fi

interp=`(uname -s) 2>/dev/null` || interp=unknown
case ${interp} in
   SunOS)
     # The following line is needed so the dynamic libs are found
     # otherwise the adapter gets a signal 9 from ovstart
     LD_LIBRARY_PATH=$OV_LIB/../lib:$LD_LIBRARY_PATH
     export LD_LIBRARY_PATH
   ;;
   HP-UX)
     # The following line is needed so the dynamic libs are found
     # otherwise the adapter gets an error that it can't connect
     # to the SNMP session.
     SHLIB_PATH=$OV_LIB/../lib:$SHLIB_PATH
     export SHLIB_PATH
   ;;
   *)
     # If the interp cannot be determined or is not 1 or
     # solaris then exit.
     echo "Could not determine what interp the machine is to set the " >> /tmp/hpov_start.err;
     echo "LD_LIBRARY_PATH(solaris) or SHLIB_PATH(hpux). Exiting....." >> /tmp/hpov_start.err;
     exit 1
   ;;
esac

 # If the Tivoli environment file exists source the environment
[ -f /etc/Tivoli/setup_env.sh ] && . /etc/Tivoli/setup_env.sh

PROD_EXE=`echo $0 | sed 's,\.sh$,,'`

 # Execute the tecad_hpov binary
exec $PROD_EXE $*

